Django: Sane Testing — Django: Sane Testing v0.4.0 documentation

### Navigation

- index
- next |
- Django: Sane Testing v0.4.0 documentation »

# Django: Sane Testing

Welcome to library that allows you to really test your Django applications. Read introduction if you’re intrested in my motivations and an overview of what this library do; look at test introduction if you want to know my approach to web testing (fundamental to project design) or proceed directly to Usage to start using it, or plugin description if you’re experienced testing/nose coder and just want the plugin reference.

Trac is available at my devel pages and downloads available from releases. Those interested can also always grab code directly from repository or track project at ohloh.

Feedback is always appreciated. Send it to bugs at almad.net, I’ll be glad to hear from you.

Published under BSD license; do what you want, just test it.

- Introduction
  - Feature overview

- Test introduction
  - Developer tests and xUnit
  - Test phases (and database)
  - HTTP Tests
  - Web tests
  - Developer’s workflow
  - Few words against Doctests

- Usage
  - Writing tests
  - Running tests
  - Plugins

- Wrap-up and Acknowledgements

### Navigation

- index
- next |
- Django: Sane Testing v0.4.0 documentation »